@@ -8,12 +8,14 @@ use char_device::TokioCharDevice;
 
 #[test]
 fn tty() {
+    const NXIO: i32 = posish::io::Error::NXIO.raw_os_error();
+
     // For now, just ensure that we can open this.
     let _tty = match CharDevice::open("/dev/tty") {
         Ok(tty) => tty,
         Err(e) => match e.raw_os_error() {
             // Headless environments sometimes lack /dev/tty.
-            Some(libc::ENXIO) => return,
+            Some(NXIO) => return,
             _ => Err(e).unwrap(),
         },
     };
@@ -22,12 +24,14 @@ fn tty() {
 #[cfg(feature = "async-std")]
 #[async_std::test]
 async fn async_std_tty() {
+    const NXIO: i32 = posish::io::Error::NXIO.raw_os_error();
+
     // For now, just ensure that we can open this.
     let _tty = match AsyncStdCharDevice::open("/dev/tty").await {
         Ok(tty) => tty,
         Err(e) => match e.raw_os_error() {
             // Headless environments sometimes lack /dev/tty.
-            Some(libc::ENXIO) => return,
+            Some(NXIO) => return,
             _ => Err(e).unwrap(),
         },
     };
@@ -36,12 +40,14 @@ async fn async_std_tty() {
 #[cfg(feature = "tokio")]
 #[tokio::test]
 async fn tokio_tty() {
+    const NXIO: i32 = posish::io::Error::NXIO.raw_os_error();
+
     // For now, just ensure that we can open this.
     let _tty = match TokioCharDevice::open("/dev/tty").await {
         Ok(tty) => tty,
         Err(e) => match e.raw_os_error() {
             // Headless environments sometimes lack /dev/tty.
-            Some(libc::ENXIO) => return,
+            Some(NXIO) => return,
             _ => Err(e).unwrap(),
         },
     };
